Returns a detailed breakdown of time spent in different parts of the tree-building algorithm. Profiling must be enabled at compile time.
Details
To enable profiling, the package must be compiled with the
-DPROFILE_PHYLOBUILD flag. This can be done by adding
PROFILE_PHYLOBUILD=1 to the PKG_CPPFLAGS in src/Makevars.
When profiling is enabled, the report shows:
Total time spent in each profiled section
Number of calls to each section
Average time per call
Percentage of total time
See also
reset_profile to clear profiling data